pub struct InstallationResults {
pub installed: Vec<Template>,
pub skipped: Vec<(String, SkippedReason)>,
pub removed: Vec<String>,
}Expand description
The results of installing a set of templates.
Fields
installed: Vec<Template>The templates that were installed during the install operation.
skipped: Vec<(String, SkippedReason)>The templates that were skipped during the install operation.
removed: Vec<String>The templates that were removed during the install operation.
Implementations